@@ -1,8 +1,8 @@
 ;;; Dezyne --- Dezyne command line tools
 ;;;
-;;; Copyright © 2020, 2021, 2022 Rutger van Beusekom <rutger@dezyne.org>
 ;;; Copyright © 2021 Paul Hoogendijk <paul@dezyne.org>
 ;;; Copyright © 2021, 2022 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+;;; Copyright © 2020, 2021, 2022, 2023 Rutger van Beusekom <rutger@dezyne.org>
 ;;;
 ;;; This file is part of Dezyne.
 ;;;
@@ -33,6 +33,7 @@
   #:use-module ((oop goops) #:renamer (lambda (x) (if (member x '(<port> <foreign>)) (symbol-append 'goops: x) x)))
   #:use-module (dzn goops)
   #:use-module (dzn ast)
+  #:use-module (dzn config)
   #:use-module (dzn display)
   #:use-module (dzn misc)
   #:use-module (dzn vm ast)
@@ -489,6 +490,18 @@ RTC-LTS->STATE-DIAGRAM."
 
    ((from label to)
      ...))"
+
+  (define (fix-queue-full-trace trace)
+    (let* ((pc (car trace))
+           (status (.status pc)))
+      (if (not (is-a? status <queue-full-error>)) trace
+          (let* ((statement (.statement pc))
+                 (illegal (make <illegal-error>
+                            #:message "illegal"
+                            #:ast statement))
+                 (illegal-pc (clone pc #:status illegal)))
+            (cons illegal-pc trace)))))
+
   (define (fix-missing-reply-trace trace)
     (match trace
       (((and ($ <program-counter>) (? (is-status? <missing-reply-error>)) error)
@@ -509,6 +522,7 @@ numbers"
     "From a run-to-completion transition PC,TRACE, generate one LTS
 triple per label in the trail of the transition."
     (let* ((trace (fix-missing-reply-trace trace))
+           (trace (fix-queue-full-trace trace))
            (labels (parameterize ((%modeling? #t))
                      (map cdr (trace->trail trace))))
            (labels (if (null? labels) '("tau") labels))
@@ -543,12 +557,15 @@ RTC-LTS->LTS."
 ;;; Entry points.
 ;;;
 
-(define* (state-diagram root #:key format model queue-size
+(define* (state-diagram root #:key format model
+                        queue-size queue-size-defer queue-size-external
                         ports? extended? actions? labels? returns?)
   "Entry-point for dzn explore --state-diagram."
   (parameterize ((%debug? (> (dzn:debugity) 0))
                  (%exploring? #t)
                  (%queue-size queue-size)
+                 (%queue-size-defer queue-size-defer)
+                 (%queue-size-external queue-size-external)
                  (%sut (runtime:get-sut root model)))
     (parameterize ((%instances (runtime:create-instances (%sut))))
       (let* ((pc (make-pc))
@@ -568,11 +585,13 @@ RTC-LTS->LTS."
                                      state-diagram (.working-directory root)))
             (display (state-diagram->dot state-diagram (pc->hash pc))))))))
 
-(define* (lts root #:key model queue-size)
+(define* (lts root #:key model queue-size queue-size-defer queue-size-external)
   "Entry-point for dzn explore --lts."
   (parameterize ((%debug? (> (dzn:debugity) 0))
                  (%exploring? #t)
                  (%queue-size queue-size)
+                 (%queue-size-defer queue-size-defer)
+                 (%queue-size-external queue-size-external)
                  (%sut (runtime:get-sut root model)))
     (parameterize ((%instances (runtime:create-instances (%sut))))
       (let* ((pc (make-pc))
