@@ -46,6 +46,8 @@
   #:use-module ((oop goops) #:renamer (lambda (x) (if (member x '(<port> <foreign>)) (symbol-append 'goops: x) x)))
   #:use-module (dzn goops)
 
+  #:declarative? #f
+
   #:export (file->ast
             file->stream
             file+import-content-alist
@@ -240,7 +242,8 @@ using CONTENT-ALIST to transform locations."
       (ast:pretty-print ast (current-error-port)))
     ast))
 
-(define* (file->ast file-name #:key debug? (imports '()) parse-tree? skip-wfc?)
+(define* (file->ast file-name #:key debug? (imports '()) parse-tree? skip-wfc?
+                    (transform '()))
   "Parse FILE-NAME and return an ast.  When PARSE-TREE?, return the
 parse trees.  When SKIP-WFC?, skip the well-formedness checks.  Unless
 @var{debug?}, handle exceptions."
@@ -248,15 +251,18 @@ parse trees.  When SKIP-WFC?, skip the well-formedness checks.  Unless
   (define (helper)
     (if (equal? file-name "-") (string->ast (read-string)
                                             #:parse-tree? parse-tree?
-                                            #:skip-wfc? skip-wfc?)
+                                            #:skip-wfc? skip-wfc?
+                                            #:transform transform)
         (let* ((content-alist dir (file+import-content-alist file-name #:imports imports))
                (parse-tree-alist (parse-file+import-content-alist content-alist)))
           (if parse-tree? parse-tree-alist
-              (let ((ast (parse-tree-alist->ast parse-tree-alist
-                                                #:content-alist content-alist
-                                                #:working-directory dir)))
-                (if skip-wfc? ast
-                    (ast:wfc ast)))))))
+              (let* ((ast (parse-tree-alist->ast parse-tree-alist
+                                                 #:content-alist content-alist
+                                                 #:working-directory dir))
+                     (ast (if skip-wfc? ast
+                              (ast:wfc ast)))
+                     (transform (map string->transformation transform)))
+                ((apply compose identity (reverse transform)) ast))))))
 
   (catch (if debug? 'none #t)
     helper
@@ -287,7 +293,7 @@ parse trees.  When SKIP-WFC?, skip the well-formedness checks.  Unless
        (apply format (current-error-port) "~a:error:~a\n" file-name args)
        (exit EXIT_FAILURE))
       ((well-formedness-error)
-       (for-each wfc:report-error args)
+       (for-each wfc:report-message args)
        (exit EXIT_FAILURE))
       ((system-error)
        (let ((errno (system-error-errno (cons key args))))
@@ -303,17 +309,19 @@ parse trees.  When SKIP-WFC?, skip the well-formedness checks.  Unless
     thunk
     (parse:handle-exceptions file-name)))
 
-(define* (string->ast string #:key parse-tree? skip-wfc?)
+(define* (string->ast string #:key parse-tree? skip-wfc? (transform '()))
   "Parse STRING and return an ast.  When PARSE-TREE?, return the parse
 trees.  When SKIP-WFC? skip the well-formedness checks."
   (let* ((content-alist dir (string->file+import-content-alist string))
          (parse-tree-alist (parse-file+import-content-alist content-alist)))
     (if parse-tree? parse-tree-alist
-        (let ((ast (parse-tree-alist->ast parse-tree-alist
-                                          #:content-alist content-alist
-                                          #:working-directory dir)))
-          (if skip-wfc? ast
-              (ast:wfc ast))))))
+        (let* ((ast (parse-tree-alist->ast parse-tree-alist
+                                           #:content-alist content-alist
+                                           #:working-directory dir))
+               (ast (if skip-wfc? ast
+                        (ast:wfc ast)))
+               (transform (map string->transformation transform)))
+          ((apply compose identity (reverse transform)) ast)))))
 
 (define (string->file+import-content-alist string)
   "Split possibly pre-processed STRING at preprocessing markers
@@ -462,3 +470,20 @@ specified in IMPORTS."
                    (map (cute cons <> file-name)
                         (imported-file-names content)))))
   (append-map parse alist))
+
+(define (string->transformation str)
+  (let* ((transform (resolve-interface `(dzn transform)))
+         (input (open-input-string str))
+         (name (false-if-exception (read input)))
+         (transformation (false-if-exception
+                          (module-ref transform name)))
+         (parameters (false-if-exception (read input)))
+         (parameters (if (pair? parameters) parameters '()))
+         (parameters? (and (pair? parameters)
+                           (match (warn "arity" (procedure-minimum-arity transformation))
+                             ((1 0 optional) #f)
+                             (_ #t)))))
+    (unless transformation
+      (throw 'error (format #f "no such transformation: ~a" str)))
+    (if parameters? (cute transformation <> parameters)
+        transformation)))
