@@ -1,7 +1,8 @@
 ;;; Dezyne --- Dezyne command line tools
 ;;;
-;;; Copyright © 2017, 2018, 2019, 2020, 2021, 2022 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+;;; Copyright © 2017, 2018, 2019, 2020, 2021, 2022, 2023 Janneke Nieuwenhuizen <janneke@gnu.org>
 ;;; Copyright © 2018 Rob Wieringa <rma.wieringa@gmail.com>
+;;; Copyright © 2022, 2023 Rutger (regtur) van Beusekom <rutger@dezyne.org>
 ;;;
 ;;; This file is part of Dezyne.
 ;;;
@@ -23,6 +24,12 @@
 ;;; Code:
 
 (define-module (dzn script)
+  #:use-module (srfi srfi-1)
+  #:use-module (srfi srfi-26)
+  #:use-module (srfi srfi-71)
+
+  #:use-module (system repl error-handling)
+
   #:use-module (ice-9 documentation)
   #:use-module (ice-9 getopt-long)
   #:use-module (ice-9 match)
@@ -30,39 +37,81 @@
   #:use-module (system repl error-handling)
   #:use-module (srfi srfi-1)
   #:use-module (srfi srfi-26)
+
+  #:use-module ((oop goops) #:renamer (lambda (x) (if (member x '(<port> <foreign>)) (symbol-append 'goops: x) x)))
+
   #:use-module (dzn config)
   #:use-module (dzn command-line)
+  #:use-module (dzn goops)
   #:use-module (dzn misc)
   #:use-module (dzn shell-util)
+  #:use-module (dzn timing)
+  #:use-module (dzn timing instrument)
+
+  #:declarative? #f ;for timing instrumentation
+
   #:export (main
-            parse-opts))
+            parse-opts
+            script:command
+            script:command-module))
+
+;; Procedures to instrument with display-duration
+;; the first entry also prints accumulated times.
+(define %time
+  `(((dzn script) run-command)
+    ((dzn parse) file+import-content-alist)
+    ((dzn parse) file->ast)
+    ((dzn parse) file->stream)
+    ((dzn parse) string->ast)
+    ((dzn ast normalize) normalize:event+illegals)
+    ((dzn ast normalize) normalize:state+illegals)
+    ((dzn code) code:normalize)
+    ((dzn code) code:normalize+determinism)
+    ((dzn code c++) ast->)
+    ((dzn code makreel) makreel:normalize)
+    ((dzn code makreel) ast->)
+    ((dzn ast wfc) wfc (,<root>))))
+
+;; Procedures to instrument with measure-duration.
+(define %measure
+  `(((dzn parse) parse-tree->ast)
+    ((dzn parse) string->parse-tree)
+    ((dzn code makreel) root->)
+    ((dzn ast accessor) ast:parent (,<ast> ,<class>))
+    ((dzn ast lookup) ast:lookup (,<ast> ,<top>))
+    ((dzn ast lookup) ast:lookup-variable (,<ast> ,<top>))))
 
 (define (parse-opts args)
   (let* ((option-spec
 	  '((debug (single-char #\d))
             (help (single-char #\h))
-	    (skip-wfc (single-char #\p))
-	    (transform (single-char #\t) (value #t))
-	    (verbose (single-char #\v))
-	    (version (single-char #\V))))
-	 (options (getopt-long args option-spec
-		               #:stop-at-first-non-option #t))
-	 (verbose? (option-ref options 'verbose #f))
-	 (help? (option-ref options 'help #f))
-	 (files (option-ref options '() '()))
-	 (usage? (and (not help?) (null? files)))
-	 (version? (option-ref options 'version #f)))
+            (repl (single-char #\R))
+            (skip-wfc (single-char #\p))
+            (timings (single-char #\T))
+            (transform (single-char #\t) (value #t))
+            (verbose (single-char #\v))
+            (version (single-char #\V))))
+         (options (getopt-long args option-spec
+                               #:stop-at-first-non-option #t))
+         (verbose? (option-ref options 'verbose #f))
+         (help? (option-ref options 'help #f))
+         (files (option-ref options '() '()))
+         (usage? (and (not help?) (null? files)))
+         (version? (option-ref options 'version #f)))
 
     (define (list-commands dir)
-      (map (cut basename <> ".go")
-           (filter
-            (cute string-contains <> dir)
-            (append-map
-             (cute list-directory <>
-                   (cute string-suffix? ".go" <>))
-             (filter directory-exists?
-                     (map (cute string-append <> "/dzn/commands/")
-                          %load-compiled-path))))))
+      (let* ((uninstalled? (getenv "DZN_UNINSTALLED"))
+             (ext path (if uninstalled? (values ".scm" %load-path)
+                           (values ".go" %load-compiled-path))))
+       (map (cut basename <> ext)
+            (filter
+             (cute string-contains <> dir)
+             (append-map
+              (cute list-directory <>
+                    (cute string-suffix? ext <>))
+              (filter directory-exists?
+                      (map (cute string-append <> "/dzn/commands/")
+                           path)))))))
 
     (when version?
       (show-version-and-exit))
@@ -98,6 +147,7 @@ Usage: dzn [OPTION]... COMMAND [COMMAND-ARGUMENT...]
   -v, --verbose          be more verbose, show progress
   -V, --version          display version
   -t, --transform=TRANS  use transformation TRANS
+  -T,--timings           show timings
 
 Commands:~a
 
@@ -115,19 +165,30 @@ Use \"dzn COMMAND --help\" for command-specific information.
 
 (define parse-opts (pure-funcq parse-opts))
 
-(define (run-command args)
-  (let* ((command (string->symbol (car args)))
-         (module (resolve-module `(dzn commands ,command)))
-         (main (and module (false-if-exception (module-ref module 'main)))))
+(define* (script:command #:key (options (parse-opts (command-line))))
+  (match (command:command-line options)
+    ((command rest ...) (string->symbol command))
+    (_ #f)))
+
+(define* (script:command-module #:key (options (parse-opts (command-line))))
+  (let ((command (script:command #:options options)))
+    (resolve-module `(dzn commands ,command))))
+
+(define (run-command options)
+  (let* ((command (script:command #:options options))
+         (module (script:command-module #:options options))
+         (main (and module (false-if-exception (module-ref module 'main))))
+         (command-args (command:command-line options)))
     (unless main
       (format (current-error-port) "dzn: no such command: ~a\n" command)
       (exit EXIT_OTHER_FAILURE))
-    (main args)))
+    (main command-args)))
 
 (define (main args)
   (let* ((options (parse-opts args))
-         (command-args (command:command-line options))
-         (command (and (pair? command-args) (car command-args)))
-         (debug? (option-ref options 'debug #f)))
-    (if (getenv "DZN_REPL") (call-with-error-handling (cut run-command command-args))
-        (run-command command-args))))
+         (repl? (option-ref options 'repl #f))
+         (timings? (option-ref options 'timings #f)))
+    (when timings?
+      (instrument-timings %time %measure))
+    (if repl? (call-with-error-handling (cute run-command options))
+        (run-command options))))
