@@ -3,7 +3,7 @@
 ;;; Copyright © 2018, 2019 Rob Wieringa <rma.wieringa@gmail.com>
 ;;; Copyright © 2018 Paul Hoogendijk <paul@dezyne.org>
 ;;; Copyright © 2018, 2021 Rutger van Beusekom <rutger@dezyne.org>
-;;; Copyright © 2018, 2019, 2020, 2021 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+;;; Copyright © 2018, 2019, 2020, 2021, 2022 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
 ;;; Copyright © 2018 Filip Toman <filip.toman@verum.com>
 ;;;
 ;;; This file is part of Dezyne.
@@ -34,11 +34,13 @@
 ;;;
 ;;; Top
 ;;;
-(define-templates import ast:import*)
+(define-templates import dzn:import* double-newline-postfix)
 (define-templates open-namespace dzn:open-namespace)
 (define-templates close-namespace dzn:open-namespace)
-(define-templates global dzn:global)
+(define-templates define-type dzn:define-type double-newline-postfix)
+(define-templates global dzn:global double-newline-postfix)
 (define-templates model dzn:model double-newline-infix)
+(define-templates comment dzn:comment)
 
 
 ;;;
@@ -51,10 +53,9 @@
 ;;;
 ;;; Interface
 ;;;
-(define-templates define-type (lambda (o) (filter (disjoin (is? <enum>) (is? <int>)) (ast:type* o))))
 (define-templates direction dzn:direction)
-(define-templates in-event (lambda (o) (filter ast:in? (ast:event* o))))
-(define-templates out-event (lambda (o) (filter ast:out? (ast:event* o))))
+(define-templates in-event ast:in-event*)
+(define-templates out-event ast:out-event*)
 (define-templates signature dzn:signature space-infix)
 (define-templates formal-type dzn:formal-type comma-infix)
 (define-templates formal ast:formal* formal-grammar)
@@ -66,8 +67,9 @@
 ;;;
 ;;; Component
 ;;;
-(define-templates provided-port (lambda (o) (filter ast:provides? (ast:port* o))))
-(define-templates required-port (lambda (o) (filter ast:requires? (ast:port* o))))
+(define-templates provides-port ast:provides-port*)
+(define-templates requires-port ast:requires-port*)
+(define-templates blocking dzn:blocking)
 (define-templates external dzn:external)
 (define-templates injected dzn:injected)
 (define-templates async-port ast:port*)
@@ -125,7 +127,7 @@
 ;;;
 (define-templates system)
 (define-templates declare-instance ast:instance*)
-(define-templates instance (lambda (o) (if (not (.instance.name o)) "" (list (.instance o)))) dot-suffix)
+(define-templates instance dzn:instance dot-suffix)
 (define-templates binding ast:binding*)
 
 
