@@ -1,7 +1,7 @@
 ;;; Dezyne --- Dezyne command line tools
 ;;;
-;;; Copyright © 2019, 2020, 2021, 2022 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
-;;; Copyright © 2020, 2021, 2022 Rutger van Beusekom <rutger@dezyne.org>
+;;; Copyright © 2019, 2020, 2021, 2022, 2023 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+;;; Copyright © 2020, 2021, 2022, 2023 Rutger van Beusekom <rutger@dezyne.org>
 ;;;
 ;;; This file is part of Dezyne.
 ;;;
@@ -29,6 +29,7 @@
   #:use-module (dzn goops)
 
   #:use-module (dzn ast)
+  #:use-module (dzn config)
   #:use-module (dzn misc)
   #:use-module (dzn vm ast)
   #:use-module (dzn vm evaluate)
@@ -126,6 +127,14 @@
       (let ((pc (set-handling! pc)))
         pc)))))
 
+(define-method (begin-step (pc <program-counter>) (instance <runtime:foreign>) (trigger <trigger>))
+  (let* ((port (.port trigger))
+         (r:port (runtime:port instance port))
+         (r:other-port (runtime:other-port r:port))
+         (trigger (clone trigger #:port.name #f))
+         (trigger (clone trigger #:parent (.type (.ast r:other-port)))))
+    (begin-step pc r:other-port trigger)))
+
 (define-method (begin-step (pc <program-counter>) (instance <runtime:port>) (trigger <trigger>))
   (%debug "* ~s ~s ~a\n" (name instance) (trigger->string trigger) "<begin-step>")
   (let* ((pc (push-pc pc trigger instance))
@@ -151,7 +160,7 @@
 
 (define-method (step (pc <program-counter>) (o <defer>))
   (let* ((defer (.defer pc)))
-    (if (= (length defer) (%queue-size))
+    (if (= (length defer) (%queue-size-defer))
         (let ((error (make <queue-full-error>
                        #:ast o
                        #:instance (.instance pc)
@@ -167,8 +176,7 @@
   (append
    (next-method pc o)
    (if (ast:modeling? (.trigger pc)) '()
-       (let ((illegal (make <implicit-illegal-error> #:ast o #:message "illegal")))
-         (list (clone pc #:previous #f #:status illegal))))))
+       (list (make-implicit-illegal pc o)))))
 
 (define-method (step (pc <program-counter>) (o <declarative-compound>))
   (%debug "  ~s ~s |~a\n" ((compose name .instance) pc) (and=> (.trigger pc) trigger->string) (name o))
@@ -659,8 +667,13 @@
        (clone pc #:statement #f))
       (($ <defer-qout>)
        (let* ((p (parent p <compound>))
-              (pc (if (not p) pc (pop-locals pc (filter (is? <variable>) (ast:statement* p))))))
-        (clone pc #:statement #f)))
+              (pc (if (not p) pc
+                      (let* ((variables (get-variables pc))
+                             (model (parent o <model>))
+                             (members (ast:member* model))
+                             (locals (drop-right variables (length members))))
+                        (pop-locals pc locals)))))
+         (clone pc #:statement #f)))
       (_
        '()))))
 
