@@ -26,7 +26,7 @@
 #include <limits>
 
 int
-main(int argc, char* argv[])
+main ()
 {
   std::cin.ignore(std::numeric_limits<std::streamsize>::max());
 
